@@ -34,6 +34,8 @@ class Config(object):
     y_scale = 1
     # If set to a filename, this will replace the default css
     base_css = None
+    # or default js
+    base_js = None
     # Style holding values injected in css
     style = DefaultStyle
     # Various font sizes
@@ -73,6 +75,7 @@ class Config(object):
     interpolate = None
     # Number of interpolated points between two values
     interpolation_precision = 250
+    zero = 0
 
     def __init__(self, **kwargs):
         """Can be instanciated with config kwargs"""
